package controller

import (
	"electricity_bill_calc/response"
	"electricity_bill_calc/security"
	"electricity_bill_calc/service"
	"fmt"
	"net/http"

	"github.com/gin-gonic/gin"
)

type _Meter04kVController struct {
	Router *gin.Engine
}

var Meter04kVController *_Meter04kVController

func InitializeMeter04kVController(router *gin.Engine) {
	Meter04kVController = &_Meter04kVController{
		Router: router,
	}

	Meter04kVController.Router.GET("/park/:pid/meter/template", security.EnterpriseAuthorize, download04kvMeterArchiveTemplate)
}

func download04kvMeterArchiveTemplate(c *gin.Context) {
	result := response.NewResult(c)
	requestParkId := c.Param("pid")
	userSession, err := _retreiveSession(c)
	if err != nil {
		result.Unauthorized(err.Error())
		return
	}
	sure, err := service.ParkService.EnsurePark(userSession.Uid, requestParkId)
	if err != nil {
		result.Error(http.StatusInternalServerError, err.Error())
		return
	}
	if !sure {
		result.Unauthorized("不能访问不属于自己的园区。")
		return
	}
	parkDetail, err := service.ParkService.FetchParkDetail(requestParkId)
	if err != nil {
		result.NotFound("未找到指定的园区信息。")
		return
	}
	c.Status(http.StatusOK)
	c.Header("Content-Type", "application/octet-stream")
	c.Header("Content-Transfer-Encoding", "binary")
	c.FileAttachment("./assets/meter_04kv_template.xlsx", fmt.Sprintf("%s-户表档案.xlsx", parkDetail.Name))
}
